### 0.12.6 {small}`2025-05-27`

```{rubric} Features
```
* Allow for `tl.leiden` and `tl.louvain` to use `float64` bit weights {pr}`374` {smaller}`S Dicks`


```{rubric} Bug fixes
```
* Fix the bug causing `pp.harmony_integrate` to use the heuristic implementation instead of the benchmark one when `colsum_algo` is set to `"benchmark"` {pr}`375` {smaller}`S Dicks`
